==> parodia_admin-1.0.2.tar.gz: lib/core/repository/feature.repository.dart <==
// POST
// /api/v1/dashboard/features/slugify

// GET
// /api/v1/dashboard/features/{id}

// PUT
// /api/v1/dashboard/features/{id}

// DELETE
// /api/v1/dashboard/features/{id}

// GET
// /api/v1/dashboard/features

// POST
// /api/v1/dashboard/features

// POST
// /api/v1/dashboard/features/{id}/recover

import 'package:parodia_admin/core/dto/feature.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class FeatureRepository {
  ParodiaHTTP? _http;

  FeatureRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<FeatureDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/features',
      param: id,
    );

    return ResponseItemDTO<FeatureDTO>(
      response: response,
      fromJson: FeatureDTO.fromJson,
    );
  }

  Future<ResponseListDTO<FeatureDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/features',
      query: query,
    );

    return ResponseListDTO<FeatureDTO>(
      response: response,
      fromJson: FeatureDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({FeatureBody? feature}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/features',
      data: feature,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, FeatureBody? feature}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/features',
      param: id,
      data: feature,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/features',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/features/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> slugify({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/features/slugify',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/feature.repository.dart <==
// POST
// /api/v1/dashboard/dashboard/features/slugify

// GET
// /api/v1/dashboard/dashboard/features/{id}

// PUT
// /api/v1/dashboard/dashboard/features/{id}

// DELETE
// /api/v1/dashboard/dashboard/features/{id}

// GET
// /api/v1/dashboard/dashboard/features

// POST
// /api/v1/dashboard/dashboard/features

// POST
// /api/v1/dashboard/dashboard/features/{id}/recover

import 'package:parodia_admin/core/dto/feature.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class FeatureRepository {
  ParodiaHTTP? _http;

  FeatureRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<FeatureDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/features',
      param: id,
    );

    return ResponseItemDTO<FeatureDTO>(
      response: response,
      fromJson: FeatureDTO.fromJson,
    );
  }

  Future<ResponseListDTO<FeatureDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/features',
      query: query,
    );

    return ResponseListDTO<FeatureDTO>(
      response: response,
      fromJson: FeatureDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({FeatureBody? feature}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/features',
      data: feature,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, FeatureBody? feature}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/features',
      param: id,
      data: feature,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/features',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/features/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> slugify({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/features/slugify',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
